@@ -11,7 +11,7 @@ from tqdm import *
 from f61d.setu import *
 
 
-VERSION = (0,5,8)
+VERSION = (0,5,9)
 VERSION = '.'.join(map(str, VERSION))
 
 
@@ -258,5 +258,5 @@ def mtank(outerPic,innerPic,output='tank.png'):
     p1 = p1.convert('L')
     p2 = img.open(innerPic)
     p2 = p2.convert('L')
-    make(p1,p2,getDesktop + '\\' + output)
+    make(p1,p2,getDesktop() + '\\' + output)
 
